@@ -729,7 +729,7 @@ static zval * read_property(zval *object, zval *member, int type, void **cache_s
 			retval = &EG(uninitialized_zval);
 		}
 	} else {
-		zend_object_handlers *std_hnd = zend_get_std_object_handlers();
+		const zend_object_handlers *std_hnd = zend_get_std_object_handlers();
 		retval = std_hnd->read_property(object, member, type, cache_slot, rv);
 	}
 
@@ -758,7 +758,7 @@ static void write_property(zval *object, zval *member, zval *value, void **cache
 	if (hnd) {
 		hnd->write_func(obj, value);
 	} else {
-		zend_object_handlers *std_hnd = zend_get_std_object_handlers();
+		const zend_object_handlers *std_hnd = zend_get_std_object_handlers();
 	    std_hnd->write_property(object, member, value, cache_slot);
 	}
 
@@ -799,7 +799,7 @@ static int object_has_property(zval *object, zval *member, int has_set_exists, v
 				   php_error_docref(NULL, E_WARNING, "Invalid value for has_set_exists");
 		}
 	} else {
-		zend_object_handlers *std_hnd = zend_get_std_object_handlers();
+		const zend_object_handlers *std_hnd = zend_get_std_object_handlers();
 		ret = std_hnd->has_property(object, member, has_set_exists, cache_slot);
 	}
 
@@ -848,7 +848,7 @@ static zval * get_property_ptr_ptr(zval *object, zval *member, int type, void **
 	if (hnd && hnd->get_ptr_ptr_func != NULL) {
 		retval = hnd->get_ptr_ptr_func(obj);
 	} else {
-		zend_object_handlers *std_hnd = zend_get_std_object_handlers();
+		const zend_object_handlers *std_hnd = zend_get_std_object_handlers();
 		retval = std_hnd->get_property_ptr_ptr(object, member, type, cache_slot);
 	}
 
@@ -889,18 +889,34 @@ static HashTable * get_gc(zval *object, zval **gc_data, int *gc_count)/*{{{*/
 	return zend_std_get_properties(object);
 }/*}}}*/
 
-#define PHP_EVENT_X_PROP_HND_DECL(x)                                                                                        \
-static zval * php_event_ ## x ## _read_property(zval *object, zval *member, int type, void **cache_slot, zval *rv) {        \
-	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                                   \
-	return (obj ? read_property(object, member, type, cache_slot, rv, (void *)obj, obj->prop_handler) : NULL);              \
-}                                                                                                                           \
-static void php_event_ ## x ## _write_property(zval *object, zval *member, zval *value, void **cache_slot)                  \
-{                                                                                                                           \
-	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                                   \
-	if (EXPECTED(obj)) {                                                                                                    \
-		write_property(object, member, value, cache_slot, (void *)obj, obj->prop_handler);                                  \
-	}                                                                                                                       \
-}                                                                                                                           \
+
+#if PHP_VERSION_ID >= 70400
+#define PHP_EVENT_X_PROP_WRITE_HND_DECL(x)                                                                  \
+static zval *php_event_ ## x ## _write_property(zval *object, zval *member, zval *value, void **cache_slot) \
+{                                                                                                           \
+	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                   \
+	if (EXPECTED(obj)) {                                                                                    \
+		write_property(object, member, value, cache_slot, (void *)obj, obj->prop_handler);                  \
+	}                                                                                                       \
+	return value;                                                                                           \
+}
+#else
+#define PHP_EVENT_X_PROP_WRITE_HND_DECL(x)                                                                  \
+static void php_event_ ## x ## _write_property(zval *object, zval *member, zval *value, void **cache_slot)  \
+{                                                                                                           \
+	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                   \
+	if (EXPECTED(obj)) {                                                                                    \
+		write_property(object, member, value, cache_slot, (void *)obj, obj->prop_handler);                  \
+	}                                                                                                       \
+}
+#endif /* PHP_VERSION >= 70400 */
+
+#define PHP_EVENT_X_PROP_HND_DECL(x)                                                                                 \
+PHP_EVENT_X_PROP_WRITE_HND_DECL(x)                                                                                   \
+static zval * php_event_ ## x ## _read_property(zval *object, zval *member, int type, void **cache_slot, zval *rv) { \
+	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                            \
+	return (obj ? read_property(object, member, type, cache_slot, rv, (void *)obj, obj->prop_handler) : NULL);       \
+}                                                                                                                    \
 static int php_event_ ## x ## _has_property(zval *object, zval *member, int has_set_exists, void **cache_slot)              \
 {                                                                                                                           \
 	Z_EVENT_X_OBJ_T(x) *obj = Z_EVENT_X_OBJ_P(x, object);                                                                   \
@@ -1091,10 +1107,6 @@ static zend_always_inline void register_classes()/*{{{*/
 /* {{{ PHP_MINIT_FUNCTION */
 PHP_MINIT_FUNCTION(event)
 {
-#if 0
-	zend_object_handlers *std_hnd = zend_get_std_object_handlers();
-#endif
-
 	memcpy(&event_event_object_handlers, zend_get_std_object_handlers(), sizeof(zend_object_handlers));
 	PHP_EVENT_SET_X_OBJ_HANDLERS(event);
 
@@ -1142,14 +1154,18 @@ PHP_MINIT_FUNCTION(event)
 
 	/* Run-time flags of event base usually passed to event_config_set_flag */
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, NOLOCK,               EVENT_BASE_FLAG_NOLOCK);
+#if LIBEVENT_VERSION_NUMBER >= 0x02000301
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, STARTUP_IOCP,         EVENT_BASE_FLAG_STARTUP_IOCP);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, NO_CACHE_TIME,        EVENT_BASE_FLAG_NO_CACHE_TIME);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, EPOLL_USE_CHANGELIST, EVENT_BASE_FLAG_EPOLL_USE_CHANGELIST);
-#ifdef EVENT_BASE_FLAG_IGNORE_ENV
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, IGNORE_ENV,           IGNORE_ENV);
 #endif
-#ifdef EVENT_BASE_FLAG_PRECISE_TIMER
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, PRECISE_TIMER,        PRECISE_TIMER);
+#if LIBEVENT_VERSION_NUMBER >= 0x02000901
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, NO_CACHE_TIME,        EVENT_BASE_FLAG_NO_CACHE_TIME);
+#endif
+#if LIBEVENT_VERSION_NUMBER >= 0x02000301
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, EPOLL_USE_CHANGELIST, EVENT_BASE_FLAG_EPOLL_USE_CHANGELIST);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, IGNORE_ENV,           EVENT_BASE_FLAG_IGNORE_ENV);
+#endif
+#if LIBEVENT_VERSION_NUMBER >= 0x02010201
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_base_ce, PRECISE_TIMER,        EVENT_BASE_FLAG_PRECISE_TIMER);
 #endif
 
 	/* Event flags */
